fn terminal_close_cause(close_code: WebSocketCloseCode) -> Option<&'static str>Expand description
Returns the compatibility cause label for a terminal WebSocket close code.
fn terminal_close_cause(close_code: WebSocketCloseCode) -> Option<&'static str>Returns the compatibility cause label for a terminal WebSocket close code.